pub fn read_label_idx(wasm: &mut WasmReader<'_>) -> Result<u32, DecodingError>Expand description
Reads a label index from Wasm code without validating it.
pub fn read_label_idx(wasm: &mut WasmReader<'_>) -> Result<u32, DecodingError>Reads a label index from Wasm code without validating it.