read_label_idx_unchecked

Function read_label_idx_unchecked 

pub unsafe fn read_label_idx_unchecked(wasm: &mut WasmReader<'_>) -> u32
Reads a label index from Wasm code without validating it.

Safety

The caller must ensure that there is a valid label index in the WasmReader.