IdxVec

Struct IdxVec 

pub struct IdxVec<I: Idx, T> {
    inner: Box<[T]>,
    _phantom: PhantomData<I>,
}
An immutable vector that can only be indexed by type-safe 32-bit indices.

Use IdxVec::new or IdxVec::default to create a new instance.

Fields

inner: Box<[T]>_phantom: PhantomData<I>

Implementations

Source

impl<I: Idx, T> IdxVec<I, T>

pub fn new(elements: Vec<T>) -> Result<Self, IdxVecOverflowError>

Creates a new IdxVec with the given elements in it.

If the number of elements is larger than what can be addressed by a u32, i.e. u32::MAX, an error is returned instead.

fn validate_index(&self, index: u32) -> Option<I>

pub unsafe fn get(&self, index: I) -> &T

Gets an element from this vector by its index.

Safety

The caller must ensure that the index object was validated using the same vector as self or a different vector used to create self through IdxVec::map.

pub fn len(&self) -> u32

pub fn iter_enumerated(&self) -> impl Iterator<Item = (I, &T)>

pub fn map<R, E>( &self, mapper: impl FnMut(&T) -> Result<R, E>, ) -> Result<IdxVec<I, R>, E>

Creates an equivalent index space for one that already exists while allowing elements to be mapped.