pub struct MemIdx(u32);Tuple Fields
0: u32Implementations
Sourceimpl MemIdx
impl MemIdx
Sourcepub fn validate<T>(
index: u32,
c_mems: &IdxVec<MemIdx, T>,
) -> Result<Self, ValidationError>
pub fn validate<T>( index: u32, c_mems: &IdxVec<MemIdx, T>, ) -> Result<Self, ValidationError>
Validates that a given index is a valid memory index.
On success a new MemIdx is returned, otherwise a ValidationError
is returned.
Sourcepub fn read_and_validate<T>(
wasm: &mut WasmReader<'_>,
c_mems: &IdxVec<MemIdx, T>,
) -> Result<Self, ValidationError>
pub fn read_and_validate<T>( wasm: &mut WasmReader<'_>, c_mems: &IdxVec<MemIdx, T>, ) -> Result<Self, ValidationError>
Reads a memory index from Wasm code and validates that it is a valid index for a given memories vector.
Sourcepub unsafe fn read_unchecked(wasm: &mut WasmReader<'_>) -> Self
pub unsafe fn read_unchecked(wasm: &mut WasmReader<'_>) -> Self
Reads a memory index from Wasm code without validating it.
Safety
The caller must ensure that there is a valid memory index in the
WasmReader and that this index is valid for a specific ExtendedIdxVec
through Self::read_and_validate.