pub struct ElemIdx(u32);Tuple Fields
0: u32Implementations
Sourceimpl ElemIdx
impl ElemIdx
Sourcepub unsafe fn decode_unchecked(wasm: &mut WasmDecoder<'_>) -> Self
pub unsafe fn decode_unchecked(wasm: &mut WasmDecoder<'_>) -> Self
Reads an element index from Wasm code without validating it.
Safety
The caller must ensure that there is a valid element index in the WasmDecoder.
Sourceimpl ElemIdx
impl ElemIdx
Sourcepub fn validate<T>(
index: u32,
c_elems: &IdxVec<ElemIdx, T>,
) -> Result<Self, ValidationError>
pub fn validate<T>( index: u32, c_elems: &IdxVec<ElemIdx, T>, ) -> Result<Self, ValidationError>
Validates that a given index is a valid element index.
On success a new ElemIdx is returned, otherwise a
ValidationError is returned.
Sourcepub fn decode_and_validate<T>(
wasm: &mut WasmDecoder<'_>,
c_elems: &IdxVec<ElemIdx, T>,
) -> Result<Self, ValidationError>
pub fn decode_and_validate<T>( wasm: &mut WasmDecoder<'_>, c_elems: &IdxVec<ElemIdx, T>, ) -> Result<Self, ValidationError>
Reads an element index from Wasm code and validates that it is a valid index for a given elements vector.