pub struct FuncIdx(u32);Tuple Fields
0: u32Implementations
Sourceimpl FuncIdx
impl FuncIdx
Sourcepub unsafe fn decode_unchecked(wasm: &mut WasmDecoder<'_>) -> Self
pub unsafe fn decode_unchecked(wasm: &mut WasmDecoder<'_>) -> Self
Reads a function index from Wasm code without validating it.
Safety
The caller must ensure that there is a valid function index in the WasmDecoder.
Sourceimpl FuncIdx
impl FuncIdx
Sourcepub fn validate<T>(
index: u32,
c_funcs: &IdxVec<FuncIdx, T>,
) -> Result<Self, ValidationError>
pub fn validate<T>( index: u32, c_funcs: &IdxVec<FuncIdx, T>, ) -> Result<Self, ValidationError>
Validates that a given index is a valid function index.
On success a new FuncIdx is returned, otherwise a
ValidationError is returned.
Sourcepub fn decode_and_validate<T>(
wasm: &mut WasmDecoder<'_>,
c_funcs: &IdxVec<FuncIdx, T>,
) -> Result<Self, ValidationError>
pub fn decode_and_validate<T>( wasm: &mut WasmDecoder<'_>, c_funcs: &IdxVec<FuncIdx, T>, ) -> Result<Self, ValidationError>
Reads a function index from Wasm code and validates that it is a valid index for a given functions vector.