pub struct MemIdx(u32);Tuple Fields
0: u32Implementations
Sourceimpl MemIdx
impl MemIdx
Sourcepub unsafe fn decode_unchecked(wasm: &mut WasmDecoder<'_>) -> Self
pub unsafe fn decode_unchecked(wasm: &mut WasmDecoder<'_>) -> Self
Reads a memory index from Wasm code without validating it.
Safety
The caller must ensure that there is a valid memory index in the WasmDecoder.
Sourceimpl MemIdx
impl MemIdx
Sourcepub fn validate<T>(
index: u32,
c_mems: &IdxVec<MemIdx, T>,
) -> Result<Self, ValidationError>
pub fn validate<T>( index: u32, c_mems: &IdxVec<MemIdx, T>, ) -> Result<Self, ValidationError>
Validates that a given index is a valid memory index.
On success a new MemIdx is returned, otherwise a ValidationError
is returned.
Sourcepub fn decode_and_validate<T>(
wasm: &mut WasmDecoder<'_>,
c_mems: &IdxVec<MemIdx, T>,
) -> Result<Self, ValidationError>
pub fn decode_and_validate<T>( wasm: &mut WasmDecoder<'_>, c_mems: &IdxVec<MemIdx, T>, ) -> Result<Self, ValidationError>
Reads a memory index from Wasm code and validates that it is a valid index for a given memories vector.