pub struct TableIdx(u32);Tuple Fields
0: u32Implementations
Sourceimpl TableIdx
impl TableIdx
Sourcepub unsafe fn decode_unchecked(wasm: &mut WasmDecoder<'_>) -> Self
pub unsafe fn decode_unchecked(wasm: &mut WasmDecoder<'_>) -> Self
Reads a table index from Wasm code without validating it.
Safety
The caller must ensure that there is a valid table index in the WasmDecoder.
Sourceimpl TableIdx
impl TableIdx
Sourcepub fn validate<T>(
index: u32,
c_tables: &IdxVec<TableIdx, T>,
) -> Result<Self, ValidationError>
pub fn validate<T>( index: u32, c_tables: &IdxVec<TableIdx, T>, ) -> Result<Self, ValidationError>
Validates that a given index is a valid table index.
On success a new TableIdx is returned, otherwise a
ValidationError is returned.
Sourcepub fn decode_and_validate<T>(
wasm: &mut WasmDecoder<'_>,
c_tables: &IdxVec<TableIdx, T>,
) -> Result<Self, ValidationError>
pub fn decode_and_validate<T>( wasm: &mut WasmDecoder<'_>, c_tables: &IdxVec<TableIdx, T>, ) -> Result<Self, ValidationError>
Reads a table index from Wasm code and validates that it is a valid index for a given tables vector.