global_get
wasm
0.2.0
global_
get
Sections
Safety
In wasm::
execution::
const_
interpreter_
loop
wasm
::
execution
::
const_interpreter_loop
Function
global_
get
unsafe fn global_get<T:
Config
>( args:
Args
<'_, '_, '_, '_, T>, ) ->
Result
<
bool
,
RuntimeError
>

Safety
the constant expression in the reader must be valid
the module address must be valid in the given store