i32_const
wasm
0.2.0
i32_
const
Sections
Safety
In wasm::
execution::
const_
interpreter_
loop
wasm
::
execution
::
const_interpreter_loop
Function
i32_
const
unsafe fn i32_const<T:
Config
>( args:
Args
<'_, '_, '_, '_, T>, ) ->
Result
<
bool
,
RuntimeError
>

Safety
the constant expression in the reader must be valid
the module address must be valid in the given store