ref_null

Function ref_null 

unsafe fn ref_null<T: Config>(
    args: Args<'_, '_, '_, '_, T>,
) -> Result<bool, RuntimeError>
Safety

  1. the constant expression in the reader must be valid
  2. the module address must be valid in the given store