run_const_span

Function run_const_span 

pub(crate) unsafe fn run_const_span<T: Config>(
    wasm: &[u8],
    span: &Span,
    module: ModuleAddr,
    store: &Store<'_, T>,
) -> Result<Option<Value>, RuntimeError>
Safety

  1. the constant expression in bytecode in the given span must be valid
  2. the module address must be valid in the given store