pub enum TrapError {
DivideBy0,
UnrepresentableResult,
BadConversionToInteger,
MemoryOrDataAccessOutOfBounds,
TableOrElementAccessOutOfBounds,
UninitializedElement,
SignatureMismatch,
IndirectCallNullFuncRef,
TableAccessOutOfBounds,
ReachedUnreachable,
}Variants
DivideBy0
UnrepresentableResult
BadConversionToInteger
MemoryOrDataAccessOutOfBounds
An access to a memory or data was out of bounds.
Note: As of now, there is no way to distinguish between both of these. The reference interpreter and Wast testsuite messages call this error “memory access out of bounds”.
TableOrElementAccessOutOfBounds
An access to a table or an element was out of bounds.
Note: As of now, there is no way to distinguish between both of these. The reference interpreter and Wast testsuite messages call this error “table access out of bounds”.
UninitializedElement
SignatureMismatch
IndirectCallNullFuncRef
TableAccessOutOfBounds
ReachedUnreachable