memory_init

Function memory_init 

pub(super) unsafe fn memory_init(
    store_modules: &AddrVec<ModuleAddr, ModuleInst<'_>>,
    store_memories: &mut AddrVec<MemAddr, MemInst>,
    store_data: &AddrVec<DataAddr, DataInst>,
    current_module: ModuleAddr,
    data_idx: DataIdx,
    mem_idx: MemIdx,
    n: u32,
    s: u32,
    d: u32,
) -> Result<(), RuntimeError>
Safety

  • The caller must ensure that the given memory index is valid in store_modules.get(current_module).mem_addrs.
  • The caller must ensure that the given data index is alid in store_modules.get(current_module).data_addrs.