pub struct InvokedResumableRef {
pub(crate) key: SlotMapKey<Resumable>,
}Expand description
Note
Dropping a resumable ref does not deallocate the resumable anymore. It is up
to the user to implement such garbage collection algorithms by using
Store::drop_resumable to prevent unnecessary memory usage.
Fields
key: SlotMapKey<Resumable>Auto Trait Implementations
impl Freeze for InvokedResumableRef
impl RefUnwindSafe for InvokedResumableRef
impl Send for InvokedResumableRef
impl Sync for InvokedResumableRef
impl Unpin for InvokedResumableRef
impl UnwindSafe for InvokedResumableRef