AddrVec

Struct AddrVec 

pub(crate) struct AddrVec<A: Addr, Inst> {
    inner: Vec<Inst>,
    _phantom: PhantomData<A>,
}

Fields

inner: Vec<Inst>_phantom: PhantomData<A>

Implementations

Source

impl<A: Addr, Inst> AddrVec<A, Inst>

pub unsafe fn get(&self, addr: A) -> &Inst

Returns an instance by its address addr.

Safety

The caller must ensure that the given address is valid in this vector.

pub unsafe fn get_mut(&mut self, addr: A) -> &mut Inst

Returns a mutable reference to some instance by its address addr.

Safety

The caller must ensure that the given address is valid in this vector.

pub(crate) fn insert(&mut self, instance: Inst) -> A

Inserts a new instance into the current Store and returns its address.

This method should always be used to insert new instances, as it is the only safe way of creating addrs.

pub(crate) unsafe fn get_two_mut( &mut self, addr_one: A, addr_two: A, ) -> Option<(&mut Inst, &mut Inst)>

Mutably borrows two instances by their addresses and returns those references. In the case where both given addresses are equal, None is returned instead.

Safety

The caller must ensure that both given addresses are valid in this vector.