pub enum RunState {
Finished {
values: Vec<Value>,
maybe_remaining_fuel: Option<u64>,
},
Resumable {
resumable: WasmResumable,
required_fuel: Option<NonZeroU64>,
},
HostCalled {
host_call: HostCall,
resumable: HostResumable,
},
}Expand description
Represents the state of a possibly interrupted resumable.
Variants
Finished
represents a resumable that has executed completely with return values values and possibly remaining fuel
maybe_remaining_fuel (has Some(remaining_fuel) for fuel-metered operations and None otherwise)
Resumable
represents a resumable that has ran out of fuel during execution, missing at least required_fuel units of fuel
to continue further execution (this is None if unknown).
HostCalled
A host function was called by Wasm code. Use the HostCall to execute
the host function and resume execution using the HostResumable and
the return values produced by execution.