pub struct HostCall {
pub params: Vec<Value>,
pub hostcode: Hostcode,
}Expand description
A HostCall object contains information required for executing a specific
host function.
Fields
params: Vec<Value>Must contain the correct parameter types for the host function with host
code hostcode.
hostcode: HostcodeTrait Implementations