read_instructions

Function read_instructions 

unsafe fn read_instructions(
    wasm: &mut WasmReader<'_>,
    stack: &mut ValidationStack,
    sidetable: &mut Vec<SidetableEntry>,
    locals: &[ValType],
    c_globals: &IdxVec<GlobalIdx, Global>,
    fn_types: &IdxVec<TypeIdx, FuncType>,
    c_funcs: &IdxVec<FuncIdx, TypeIdx>,
    c_mems: &IdxVec<MemIdx, MemType>,
    data_count: Option<u32>,
    c_tables: &IdxVec<TableIdx, TableType>,
    c_elems: &IdxVec<ElemIdx, ElemType>,
    validation_context_refs: &BTreeSet<FuncIdx>,
) -> Result<(), ValidationError>
Safety

The caller must ensure that all index values passed into this function are valid in the relevant IdxVec. The following table lists all index types and their respective IdxVec types: