validate_code_section

Function validate_code_section 

pub unsafe fn validate_code_section(
    wasm: &mut WasmReader<'_>,
    section_header: SectionHeader,
    fn_types: &IdxVec<TypeIdx, FuncType>,
    c_funcs: &ExtendedIdxVec<FuncIdx, TypeIdx>,
    c_globals: &IdxVec<GlobalIdx, Global>,
    c_mems: &IdxVec<MemIdx, MemType>,
    data_count: Option<u32>,
    c_tables: &IdxVec<TableIdx, TableType>,
    c_elems: &IdxVec<ElemIdx, ElemType>,
    validation_context_refs: &BTreeSet<FuncIdx>,
    sidetable: &mut Vec<SidetableEntry>,
) -> Result<Vec<(Span, usize)>, ValidationError>
Safety

The caller must ensure that all index values passed into this function are valid in the relevant IdxVec. The following table lists all index types and their respective IdxVec types: