read_all_custom_sections

Function read_all_custom_sections 

fn read_all_custom_sections<'wasm>(
    wasm: &mut WasmReader<'wasm>,
    section_header: &mut Option<SectionHeader>,
    custom_sections: &mut Vec<CustomSection<'wasm>>,
) -> Result<(), ValidationError>
Reads the next sections as long as they are custom sections and pushes them into the custom_sections vector.