pub unsafe fn read_label_idx_unchecked(wasm: &mut WasmReader<'_>) -> u32Expand description
Reads a label index from Wasm code without validating it.
Safety
The caller must ensure that there is a valid label index in the
WasmReader.
pub unsafe fn read_label_idx_unchecked(wasm: &mut WasmReader<'_>) -> u32Reads a label index from Wasm code without validating it.
The caller must ensure that there is a valid label index in the
WasmReader.