pub(crate) unsafe fn run_const_span<T: Config>(
wasm: &[u8],
span: &Span,
module: ModuleAddr,
store: &Store<'_, T>,
) -> Result<Option<Value>, RuntimeError>Expand description
Safety
- the constant expression in bytecode in the given span must be valid
- the module address must be valid in the given store