pub enum InterpreterLoopOutcome {
ExecutionReturned,
OutOfFuel {
required_fuel: NonZeroU64,
},
HostCalled {
func_addr: FuncAddr,
params: Vec<Value>,
hostcode: Hostcode,
},
}Expand description
A non-error outcome of execution of the interpreter loop
Variants
ExecutionReturned
Execution has returned normally, i.e. the end of the bottom-most function on the stack was reached.
OutOfFuel
Execution was preempted because there was not enough fuel in the
WasmResumable object.
Fields

required_fuel: NonZeroU64The amount of fuel required to continue execution at least the next instruction.
HostCalled