Function table_init
Source pub(super) unsafe fn table_init(
store_modules: &AddrVec<ModuleAddr, ModuleInst<'_>>,
store_tables: &mut AddrVec<TableAddr, TableInst>,
store_elements: &AddrVec<ElemAddr, ElemInst>,
current_module: ModuleAddr,
elem_idx: ElemIdx,
table_idx: TableIdx,
n: u32,
s: i32,
d: i32,
) -> Result<(), RuntimeError>
Safety
- The caller must ensure that the given table index is valid in
store_modules.get(current_module).table_addrs.
- The caller must ensure that the given element index is valid in
store_modules.get(current_module).elem_addrs.