pub struct HostResumable {
pub(crate) host_func_addr: FuncAddr,
pub(crate) inner_resumable: Option<WasmResumable>,
pub(crate) maybe_fuel: Option<Option<u64>>,
}Expand description
A HostResumable is used to resume execution after executing its
HostCall.
When a host function is called, a HostResumable and HostCall are
returned. After the HostCall was used to execute the host function, the
HostResumable is used together with the return values of the host call
to resume execution.
Fields
host_func_addr: FuncAddrinner_resumable: Option<WasmResumable>maybe_fuel: Option<Option<u64>>Hack: This is Some only if inner_resumable is None. In that case
it is used to store the maybe_fuel, so it can be returned in
RunState::Finished later.