pub struct WasmResumable {
pub(crate) stack: Stack,
pub(crate) pc: usize,
pub(crate) stp: usize,
pub(crate) current_func_addr: FuncAddr,
pub(crate) maybe_fuel: Option<u64>,
}Expand description
Safety
TODO:
- stack must be initialized with correct parameters to function referenced by function address
- program counter must be valid for the bytecode of function referenced by the function address
- stp must point to the correct sidetable entry for the function referenced by function address
Fields
stack: Stackpc: usizestp: usizecurrent_func_addr: FuncAddrmaybe_fuel: Option<u64>Trait Implementations